## 0.1.0 (Unreleased)
### Addded
- добавлена команда ``eatme branch``
- вывод полного имени бранча при возникновении ошибки в ``eatme update -b BRANCH``
- вывод ``help`` в случае неправильного ввода команды

### Fixed
- обработка ошибок в ``eatme push``

## 0.0.15 (2015-11-03)
### Fixed
- добавлена обработка ошибки ``changesets found``

## 0.0.14 (2015-11-03)
### Fixed
- исправлена ошибка при использованиии атрибута ``--branch``

## 0.0.13 (2015-11-02)
### Fixed
- добавлена обработка ошибки ``no changes found``

## 0.0.12 (2015-11-02)
Первый публичный релиз